import { APIClient } from "./ApiClient";

export interface Account {
  id: number;
  name: string;
  user_id: number;
  time_create: number;
  time_update: number;
  default_account: boolean;
}

export class AccountsList {
  list: Account[];

  constructor(list: Account[]) {
    this.list = list;
    this.list.sort((a, b) => a.id - b.id);
  }

  /**
   * Get a single account by its id
   */
  get(id: number): Account | null {
    return this.list.find((a) => a.id === id) ?? null;
  }
}

export class AccountApi {
  /**
   * Get the current list of accounts of the user
   */
  static async GetList(): Promise<AccountsList> {
    const array = (
      await APIClient.exec({
        uri: "/accounts",
        method: "GET",
      })
    ).data;

    return new AccountsList(array);
  }

  /**
   * Set default account
   */
  static async SetDefaultAccount(account: Account): Promise<void> {
    await APIClient.exec({
      uri: `/account/${account.id}/default`,
      method: "PUT",
    });
  }

  /**
   * Update account
   */
  static async Update(account: Account): Promise<void> {
    await APIClient.exec({
      uri: `/account/${account.id}`,
      method: "PUT",
      jsonData: {
        name: account.name,
      },
    });
  }
}
